summaryrefslogtreecommitdiffstats
path: root/kmail/kmheaders.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
commitfd5d099065a748cac49e20a13481f85666c53c71 (patch)
treea0f1672cd88eb0e69b9ddc2ed9b08ecd98538bd3 /kmail/kmheaders.h
parentb440a9c608596cd88efdb3bfa4661c5e37efbe4b (diff)
downloadtdepim-fd5d099065a748cac49e20a13481f85666c53c71.tar.gz
tdepim-fd5d099065a748cac49e20a13481f85666c53c71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kmail/kmheaders.h')
-rw-r--r--kmail/kmheaders.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/kmheaders.h b/kmail/kmheaders.h
index b894b0c7..7312189f 100644
--- a/kmail/kmheaders.h
+++ b/kmail/kmheaders.h
@@ -25,7 +25,7 @@ class KMMessage;
class KMMsgBase;
class KMCommand;
class KMMainWidget;
-class KPopupMenu;
+class TDEPopupMenu;
class TQPalette;
class TQPixmap;
class TQIconSet;
@@ -45,7 +45,7 @@ enum NestingPolicy { AlwaysOpen = 0, DefaultOpen, DefaultClosed, OpenUnread };
#define KMAIL_RESERVED 3
/** The widget that shows the contents of folders */
-class KMHeaders : public KListView
+class KMHeaders : public TDEListView
{
Q_OBJECT
@@ -135,9 +135,9 @@ public:
virtual void readColorConfig(void);
/**
* Same as KListView::restoreLayout(), only that this does _not_ restore the sort order.
* This is useful since restoreLayout() doesn't restore the sort order correctly, as
* KListView doesn't know about our extended sort order like date of arrival.
*
* Note that if you want to restore the sort order correctly, call readConfig().
*/
@@ -223,7 +223,7 @@ signals:
void messageListUpdated();
/** emitted after a new item has been fully built and added to the
* list view. We can't use KListView::itemAdded, as that is emitted
* from the ctor of the item, at which point the building of the item
* is not yet far enough along to update the quick search, which is
* what is connected to this signal. */
@@ -467,7 +467,7 @@ private:
bool mReaderWindowActive;
/** popup to switch columns */
- KPopupMenu* mPopup;
+ TDEPopupMenu* mPopup;
// copied messages
TQValueList<TQ_UINT32> mCopiedMessages;
@@ -135,9 +135,9 @@ public:
virtual void readColorConfig(void);
/**
- * Same as KListView::restoreLayout(), only that this does _not_ restore the sort order.
+ * Same as TDEListView::restoreLayout(), only that this does _not_ restore the sort order.
* This is useful since restoreLayout() doesn't restore the sort order correctly, as
@@ -135,9 +135,9 @@ public:
* This is useful since restoreLayout() doesn't restore the sort order correctly, as
- * KListView doesn't know about our extended sort order like date of arrival.
+ * TDEListView doesn't know about our extended sort order like date of arrival.
*
* Note that if you want to restore the sort order correctly, call readConfig().
@@ -223,7 +223,7 @@ signals:
void messageListUpdated();
/** emitted after a new item has been fully built and added to the
- * list view. We can't use KListView::itemAdded, as that is emitted
+ * list view. We can't use TDEListView::itemAdded, as that is emitted
* from the ctor of the item, at which point the building of the item
* is not yet far enough along to update the quick search, which is